@@ -70,33 +70,36 @@ def remove_body(client, api_config, event):
     :param event: a transaction or error event
     :return: The modified event
     """
-    if event is not None:
-        body_capture = api_config[
-            "body_capture"] if api_config is not None else client.client.config.account_api_configuration.get(
-            'body_capture')
-        if body_capture == "Off":
-            logger.debug('Body capture is turned off. Removing body')
-            event["request"]['body'] = ''
-            if "response" in event and "body" in event["response"]:
-                event["response"]['body'] = ''
-        elif body_capture == "OnError":
-            not_has_error = "error" not in event
-            has_successful_status_code = "response" in event and "status_code" in event["response"] and event["response"]["status_code"] < 400
-            if not_has_error and has_successful_status_code:
-                logger.debug('Body capture is OnError. Removing body')
+    try:
+        if event is not None:
+            body_capture = api_config[
+                "body_capture"] if api_config is not None else client.client.config.account_api_configuration.get(
+                'body_capture')
+            if body_capture == "Off":
+                logger.debug('Body capture is turned off. Removing body')
                 event["request"]['body'] = ''
+                if "response" in event and "body" in event["response"]:
+                    event["response"]['body'] = ''
+            elif body_capture == "OnError":
+                not_has_error = "error" not in event
+                has_successful_status_code = "response" in event and "status_code" in event["response"] and event["response"]["status_code"] < 400
+                if not_has_error and has_successful_status_code:
+                    logger.debug('Body capture is OnError. Removing body')
+                    event["request"]['body'] = ''
+                    event["response"]['body'] = ''
+
+            if event["request"].get("body", None) is not None and len(event["request"]['body']) > MAX_BODY_SIZE:
+                event["request"]['body'] = ''
+                event["request"]['bodyLimitExceeded'] = True
+
+            if 'response' in event and event["response"].get('body', None) is not None and len(event["response"]['body']) > MAX_BODY_SIZE:
                 event["response"]['body'] = ''
+                event["response"]['bodyLimitExceeded'] = True
 
-        if len(event["request"]['body']) > MAX_BODY_SIZE:
-            event["request"]['body'] = ''
-            event["request"]['bodyLimitExceeded'] = True
-
-        if 'response' in event and event["response"].get('body', None) is not None and len(event["response"]['body']) > MAX_BODY_SIZE:
-            event["response"]['body'] = ''
-            event["response"]['bodyLimitExceeded'] = True
-
-    return event
-
+        return event
+    except Exception as ex:
+        logger.debug('Error caught removing body %s', ex)
+        return event
 
 # def sanitize_http_request_cookies(client, api_config, event):
 #     """
